#
# spec file for package libpsm2
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define psm_so 2
Name:           libpsm2
Version:        10.2.103
Release:        2.6
Summary:        Intel PSM Messaging API libraries
License:        BSD-2-Clause or GPL-2.0
Group:          Development/Libraries/C and C++
Url:            https://github.com/01org/opa-psm2/
Source:         %{name}-%{version}.tar.bz2
Source1:        libpsm2.changelog
Patch2:         libpsm2-use_RPM_OPT_FLAGS.patch
Patch3:         libpsm2-use-exported-variable-for-version-and-release.patch
Patch4:         libpsm2-include-ioctl_h.patch
BuildRequires:  libuuid-devel
BuildRequires:  pkg-config
BuildRequires:  udev
Conflicts:      opa-libs
Obsoletes:      hfi-psm
Obsoletes:      hfi-psm-debuginfo
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
#Currently *only* builds on x86_64
ExclusiveArch:  x86_64

%description
The PSM Messaging API, or PSM API, is Intel's low-level
user-level communications interface for the Truescale
family of products. PSM users are enabled with mechanisms
necessary to implement higher level communications
interfaces in parallel environments.

%package     -n %{name}-%{psm_so}
Summary:        Intel PSM Messaging API library
Group:          System/Libraries
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Provides:       %{name} = %{version}

%description -n %{name}-%{psm_so}
libpsm2 provides PSM Messaging API, or PSM API, is Intel's low-level
user-level communications interface for the Truescale
family of products. This package contains the runtime library.

%package        devel
Summary:        Development files for the Intel PSM Messaging API
Group:          Development/Libraries/C and C++
Requires:       %{name}-%{psm_so} = %{version}
Requires:       libuuid-devel
Conflicts:      opa-devel

%package        compat
Summary:        Compatibility library providing the old PSM API/ABI
Group:          Development/Libraries/C and C++
Requires:       %{name}-%{psm_so} = %{version}
#Obsoletes:      hfi-psm-compat

%description    devel
Development files for the libpsm2 library.

%description    compat
Support for MPIs linked with PSM versions < 2.

%prep
%setup -q -n %{name}-%{version}
%patch2
%patch3 -p1
%patch4 -p1

cp %{S:1} ChangeLog

%build
export RPM_OPT_FLAGS
export VERSION=${Version} RELEASE=${Release}
make %{?_smp_mflags}

%install
export DESTDIR=%{buildroot}
make %{?_smp_mflags} DESTDIR=%{buildroot} install
mkdir -p -m 0755 -p %{buildroot}/%{_libdir}/psm2
install -m0644 %{buildroot}/%{_libdir}/psm2-compat/libpsm_infinipath.so.1 %{buildroot}/%{_libdir}/psm2/libpsm_infinipath.so.1
# removing file to get rid of rpm errors
rm  %{buildroot}/%{_libdir}/psm2-compat/libpsm_infinipath.so.1
rm  %{buildroot}/%{_libexecdir}/%name/libpsm2-compat.cmds

%post -n %{name}-%{psm_so} -p /sbin/ldconfig
%postun -n %{name}-%{psm_so} -p /sbin/ldconfig
%post devel -p /sbin/ldconfig
%postun devel -p /sbin/ldconfig

%files -n %{name}-%{psm_so}
%defattr(-,root,root,-)
%{_libdir}/libpsm2.so.*
%{_udevrulesdir}/40-psm.rules
%doc COPYING README ChangeLog

%files devel
%defattr(-,root,root,-)
%{_libdir}/libpsm2.so
%{_includedir}/psm2.h
%{_includedir}/psm2_mq.h
%{_includedir}/psm2_am.h

# The following files were part of the devel-noship and moved to devel:
%dir %{_includedir}/hfi1diag/
%dir %{_includedir}/hfi1diag/linux-x86_64/
%dir %{_includedir}/hfi1diag/ptl_ips/

%{_includedir}/hfi1diag/ptl_ips/ipserror.h
%{_includedir}/hfi1diag/linux-x86_64/bit_ops.h
%{_includedir}/hfi1diag/linux-x86_64/sysdep.h
%_includedir/hfi1diag/hfi1_deprecated.h
%{_includedir}/hfi1diag/opa_udebug.h
%{_includedir}/hfi1diag/opa_debug.h
%{_includedir}/hfi1diag/opa_intf.h
%{_includedir}/hfi1diag/opa_user.h
%{_includedir}/hfi1diag/opa_service.h
%{_includedir}/hfi1diag/opa_common.h
%{_includedir}/hfi1diag/opa_byteorder.h
%{_includedir}/hfi1diag/opa_revision.h
%{_includedir}/hfi1diag/psm2_mock_testing.h
%{_includedir}/hfi1diag/psmi_wrappers.h

%files compat
%defattr(-,root,root,-)
%dir %{_libdir}/psm2/
%dir %{_sysconfdir}/modprobe.d

%{_libdir}/psm2/libpsm_infinipath.so.*
%{_udevrulesdir}/40-psm-compat.rules
%config %{_sysconfdir}/modprobe.d/libpsm2-compat.conf

%changelog
* Fri May 19 2017 nmoreychaisemartin@suse.com
- libpsm2-2 provides libpsm2 (bsc#1039855)
* Mon May 15 2017 nmoreychaisemartin@suse.com
- Fix package version numbering (bsc#1037661).
* Fri Apr  7 2017 pth@suse.de
- Remove leftover conflict marker
* Wed Mar 29 2017 pth@suse.de
- Fix summary for libpsm2-compat.
* Mon Mar 13 2017 jengelh@inai.de
- Rectify RPM groups and refine description
* Thu Mar  9 2017 josef.moellers@suse.com
- Update to latest Intel version:
    Sync with PSM2 master upto fixes for CMA get/put
    In addition to Dynamic CMA failover support, this code surface
    includes-
  * Improved output array_of_errors in psm_ep_connect,
  * Improved signal handling for SIGSEGV/SIGBUS events
  * New abstraction layer for driver commands
  * Ubuntu packaging support
    ... and some bug fixes.
    JM: This obsoletes my libpsm2-calc-checksum.patch.
- Include sys/ioctl.h in psmi_wrappers.c
- Add hfi1diag/psmi_wrappers.h to installed files.
  (FATE#321472, bnc#990171, libpsm2-include-ioctl_h.patch)
* Fri Mar  3 2017 josef.moellers@suse.com
- Update to new version 10.3.1, mainly bug fixes
  Intel has not made available any changelog.
  As Intel's source did not compile, replaced calculation of the
  hash
- Deleted file
  libpsm2-avoid-executable-flag-on-installed-header-files.patch
  (bnc#1024057, libpsm2-calc-checksum.patch, FATE#321472)
* Tue Dec  6 2016 pth@suse.de
- Update to 10.2.2. As 0.7 isn't mentioned in the log, see
  ChangeLog for any changes to the package.
- Remove libpsm2-avoid-executable-flag-on-installed-header-files.patch
  as the fix is upstream.
- Adapt the remaining patches to the changed sources.
- Generate ChangeLog from git log and package it.
* Thu Jun  9 2016 ndas@suse.de
- Removed git from buildrequires and specify version and revision using
  environment variables (bsc#983235).
  [+libpsm2-use-exported-variable-for-version-and-release.patch]
- Added a _service file(bsc#983235).
* Fri May 27 2016 ndas@suse.de
- Removed hfi1_user.h from the source as the required changes
  are available in kernel-devel's hfi1_user.h(bsc#980733).
  [-hfi1_user.h]
* Wed Mar 23 2016 ndas@suse.de
- Fix build error (bsc#972292).
* Fri Mar 11 2016 pth@suse.de
- Fix dependency of libpsm2-devel and -compat(bsc#970895).
* Wed Mar  9 2016 pth@suse.de
- Add libpsm2-use_RPM_OPT_FLAGS.patch to include RPM_OPT_FLAGS
  in CFLAGS.
- Do not recreate RPM_BUILD_ROOT.
- Remove unneeded %%clean section
* Wed Mar  2 2016 nirmoy.das@suse.com
- Initial Package, Version 0.7(fate#319243).
